@@ -15,29 +15,23 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
-from google.oauth2 import service_account  # type: ignore
-
-from google.cloud.assuredworkloads_v1.types import assuredworkloads
 from google.longrunning import operations_pb2  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-assured-workloads",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+from google.cloud.assuredworkloads_v1 import gapic_version as package_version
+from google.cloud.assuredworkloads_v1.types import assuredworkloads
+
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 class AssuredWorkloadsServiceTransport(abc.ABC):
@@ -51,7 +45,7 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
         self,
         *,
         host: str = DEFAULT_HOST,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -140,6 +134,11 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.restrict_allowed_resources: gapic_v1.method.wrap_method(
+                self.restrict_allowed_resources,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.delete_workload: gapic_v1.method.wrap_method(
                 self.delete_workload,
                 default_timeout=None,
@@ -155,6 +154,21 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.list_violations: gapic_v1.method.wrap_method(
+                self.list_violations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_violation: gapic_v1.method.wrap_method(
+                self.get_violation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.acknowledge_violation: gapic_v1.method.wrap_method(
+                self.acknowledge_violation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
     def close(self):
@@ -189,6 +203,18 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def restrict_allowed_resources(
+        self,
+    ) -> Callable[
+        [assuredworkloads.RestrictAllowedResourcesRequest],
+        Union[
+            assuredworkloads.RestrictAllowedResourcesResponse,
+            Awaitable[assuredworkloads.RestrictAllowedResourcesResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
     @property
     def delete_workload(
         self,
@@ -219,6 +245,60 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def list_violations(
+        self,
+    ) -> Callable[
+        [assuredworkloads.ListViolationsRequest],
+        Union[
+            assuredworkloads.ListViolationsResponse,
+            Awaitable[assuredworkloads.ListViolationsResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_violation(
+        self,
+    ) -> Callable[
+        [assuredworkloads.GetViolationRequest],
+        Union[assuredworkloads.Violation, Awaitable[assuredworkloads.Violation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def acknowledge_violation(
+        self,
+    ) -> Callable[
+        [assuredworkloads.AcknowledgeViolationRequest],
+        Union[
+            assuredworkloads.AcknowledgeViolationResponse,
+            Awaitable[assuredworkloads.AcknowledgeViolationResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def list_operations(
+        self,
+    ) -> Callable[
+        [operations_pb2.ListOperationsRequest],
+        Union[
+            operations_pb2.ListOperationsResponse,
+            Awaitable[operations_pb2.ListOperationsResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_operation(
+        self,
+    ) -> Callable[
+        [operations_pb2.GetOperationRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def kind(self) -> str:
         raise NotImplementedError()
