@@ -16,16 +16,27 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.assuredworkloads_v1beta1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -33,16 +44,18 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.longrunning import operations_pb2
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.assuredworkloads_v1beta1.services.assured_workloads_service import (
     pagers,
 )
 from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads
-from google.longrunning import operations_pb2
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import AssuredWorkloadsServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import AssuredWorkloadsServiceGrpcAsyncIOTransport
+
 from .client import AssuredWorkloadsServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, AssuredWorkloadsServiceTransport
+from .transports.grpc_asyncio import AssuredWorkloadsServiceGrpcAsyncIOTransport
 
 
 class AssuredWorkloadsServiceAsyncClient:
@@ -135,7 +148,7 @@ class AssuredWorkloadsServiceAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -172,9 +185,9 @@ class AssuredWorkloadsServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, AssuredWorkloadsServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the assured workloads service client.
@@ -218,18 +231,25 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def create_workload(
         self,
-        request: Union[assuredworkloads.CreateWorkloadRequest, dict] = None,
+        request: Optional[Union[assuredworkloads.CreateWorkloadRequest, dict]] = None,
         *,
-        parent: str = None,
-        workload: assuredworkloads.Workload = None,
+        parent: Optional[str] = None,
+        workload: Optional[assuredworkloads.Workload] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates Assured Workload.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import assuredworkloads_v1beta1
 
             async def sample_create_workload():
@@ -251,13 +271,13 @@ class AssuredWorkloadsServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.assuredworkloads_v1beta1.types.CreateWorkloadRequest, dict]):
+            request (Optional[Union[google.cloud.assuredworkloads_v1beta1.types.CreateWorkloadRequest, dict]]):
                 The request object. Request for creating a workload.
             parent (:class:`str`):
                 Required. The resource name of the new Workload's
@@ -340,12 +360,12 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def update_workload(
         self,
-        request: Union[assuredworkloads.UpdateWorkloadRequest, dict] = None,
+        request: Optional[Union[assuredworkloads.UpdateWorkloadRequest, dict]] = None,
         *,
-        workload: assuredworkloads.Workload = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        workload: Optional[assuredworkloads.Workload] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> assuredworkloads.Workload:
         r"""Updates an existing workload. Currently allows updating of
@@ -355,6 +375,13 @@ class AssuredWorkloadsServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import assuredworkloads_v1beta1
 
             async def sample_update_workload():
@@ -377,7 +404,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.assuredworkloads_v1beta1.types.UpdateWorkloadRequest, dict]):
+            request (Optional[Union[google.cloud.assuredworkloads_v1beta1.types.UpdateWorkloadRequest, dict]]):
                 The request object. Request for Updating a workload.
             workload (:class:`google.cloud.assuredworkloads_v1beta1.types.Workload`):
                 Required. The workload to update. The workload's
@@ -448,10 +475,12 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def restrict_allowed_resources(
         self,
-        request: Union[assuredworkloads.RestrictAllowedResourcesRequest, dict] = None,
+        request: Optional[
+            Union[assuredworkloads.RestrictAllowedResourcesRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> assuredworkloads.RestrictAllowedResourcesResponse:
         r"""Restrict the list of resources allowed in the
@@ -465,6 +494,13 @@ class AssuredWorkloadsServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import assuredworkloads_v1beta1
 
             async def sample_restrict_allowed_resources():
@@ -484,7 +520,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.assuredworkloads_v1beta1.types.RestrictAllowedResourcesRequest, dict]):
+            request (Optional[Union[google.cloud.assuredworkloads_v1beta1.types.RestrictAllowedResourcesRequest, dict]]):
                 The request object. Request for restricting list of
                 available resources in Workload environment.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -529,11 +565,11 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def delete_workload(
         self,
-        request: Union[assuredworkloads.DeleteWorkloadRequest, dict] = None,
+        request: Optional[Union[assuredworkloads.DeleteWorkloadRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the workload. Make sure that workload's direct children
@@ -545,6 +581,13 @@ class AssuredWorkloadsServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import assuredworkloads_v1beta1
 
             async def sample_delete_workload():
@@ -560,7 +603,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 await client.delete_workload(request=request)
 
         Args:
-            request (Union[google.cloud.assuredworkloads_v1beta1.types.DeleteWorkloadRequest, dict]):
+            request (Optional[Union[google.cloud.assuredworkloads_v1beta1.types.DeleteWorkloadRequest, dict]]):
                 The request object. Request for deleting a Workload.
             name (:class:`str`):
                 Required. The ``name`` field is used to identify the
@@ -626,17 +669,24 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def get_workload(
         self,
-        request: Union[assuredworkloads.GetWorkloadRequest, dict] = None,
+        request: Optional[Union[assuredworkloads.GetWorkloadRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> assuredworkloads.Workload:
         r"""Gets Assured Workload associated with a CRM Node
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import assuredworkloads_v1beta1
 
             async def sample_get_workload():
@@ -655,7 +705,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.assuredworkloads_v1beta1.types.GetWorkloadRequest, dict]):
+            request (Optional[Union[google.cloud.assuredworkloads_v1beta1.types.GetWorkloadRequest, dict]]):
                 The request object. Request for fetching a workload.
             name (:class:`str`):
                 Required. The resource name of the Workload to fetch.
@@ -728,12 +778,14 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def analyze_workload_move(
         self,
-        request: Union[assuredworkloads.AnalyzeWorkloadMoveRequest, dict] = None,
+        request: Optional[
+            Union[assuredworkloads.AnalyzeWorkloadMoveRequest, dict]
+        ] = None,
         *,
-        project: str = None,
-        target: str = None,
+        project: Optional[str] = None,
+        target: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> assuredworkloads.AnalyzeWorkloadMoveResponse:
         r"""Analyze if the source Assured Workloads can be moved
@@ -741,6 +793,13 @@ class AssuredWorkloadsServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import assuredworkloads_v1beta1
 
             async def sample_analyze_workload_move():
@@ -760,7 +819,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.assuredworkloads_v1beta1.types.AnalyzeWorkloadMoveRequest, dict]):
+            request (Optional[Union[google.cloud.assuredworkloads_v1beta1.types.AnalyzeWorkloadMoveRequest, dict]]):
                 The request object. A request to analyze a hypothetical
                 move of a source project or project-based workload to a
                 target (destination) folder-based workload.
@@ -849,17 +908,24 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def list_workloads(
         self,
-        request: Union[assuredworkloads.ListWorkloadsRequest, dict] = None,
+        request: Optional[Union[assuredworkloads.ListWorkloadsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListWorkloadsAsyncPager:
         r"""Lists Assured Workloads under a CRM Node.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import assuredworkloads_v1beta1
 
             async def sample_list_workloads():
@@ -879,7 +945,7 @@ class AssuredWorkloadsServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.assuredworkloads_v1beta1.types.ListWorkloadsRequest, dict]):
+            request (Optional[Union[google.cloud.assuredworkloads_v1beta1.types.ListWorkloadsRequest, dict]]):
                 The request object. Request for fetching workloads in an
                 organization.
             parent (:class:`str`):
@@ -960,10 +1026,10 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def list_operations(
         self,
-        request: operations_pb2.ListOperationsRequest = None,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.ListOperationsResponse:
         r"""Lists operations that match the specified filter in the request.
@@ -1014,10 +1080,10 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -1073,14 +1139,9 @@ class AssuredWorkloadsServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-assured-workloads",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("AssuredWorkloadsServiceAsyncClient",)
