@@ -13,22 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
-import grpc  # type: ignore
-
-from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads_v1beta1
 from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
-from .base import AssuredWorkloadsServiceTransport, DEFAULT_CLIENT_INFO
+import grpc  # type: ignore
+
+from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads
+
+from .base import DEFAULT_CLIENT_INFO, AssuredWorkloadsServiceTransport
 
 
 class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
@@ -50,17 +48,18 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
         self,
         *,
         host: str = "assuredworkloads.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        channel: grpc.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        channel: Optional[grpc.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -157,6 +156,7 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -183,8 +183,8 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
     def create_channel(
         cls,
         host: str = "assuredworkloads.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
         **kwargs,
@@ -228,8 +228,7 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -249,9 +248,7 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
     @property
     def create_workload(
         self,
-    ) -> Callable[
-        [assuredworkloads_v1beta1.CreateWorkloadRequest], operations_pb2.Operation
-    ]:
+    ) -> Callable[[assuredworkloads.CreateWorkloadRequest], operations_pb2.Operation]:
         r"""Return a callable for the create workload method over gRPC.
 
         Creates Assured Workload.
@@ -269,7 +266,7 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
         if "create_workload" not in self._stubs:
             self._stubs["create_workload"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/CreateWorkload",
-                request_serializer=assuredworkloads_v1beta1.CreateWorkloadRequest.serialize,
+                request_serializer=assuredworkloads.CreateWorkloadRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_workload"]
@@ -277,10 +274,7 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
     @property
     def update_workload(
         self,
-    ) -> Callable[
-        [assuredworkloads_v1beta1.UpdateWorkloadRequest],
-        assuredworkloads_v1beta1.Workload,
-    ]:
+    ) -> Callable[[assuredworkloads.UpdateWorkloadRequest], assuredworkloads.Workload]:
         r"""Return a callable for the update workload method over gRPC.
 
         Updates an existing workload. Currently allows updating of
@@ -301,20 +295,59 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
         if "update_workload" not in self._stubs:
             self._stubs["update_workload"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/UpdateWorkload",
-                request_serializer=assuredworkloads_v1beta1.UpdateWorkloadRequest.serialize,
-                response_deserializer=assuredworkloads_v1beta1.Workload.deserialize,
+                request_serializer=assuredworkloads.UpdateWorkloadRequest.serialize,
+                response_deserializer=assuredworkloads.Workload.deserialize,
             )
         return self._stubs["update_workload"]
 
+    @property
+    def restrict_allowed_resources(
+        self,
+    ) -> Callable[
+        [assuredworkloads.RestrictAllowedResourcesRequest],
+        assuredworkloads.RestrictAllowedResourcesResponse,
+    ]:
+        r"""Return a callable for the restrict allowed resources method over gRPC.
+
+        Restrict the list of resources allowed in the
+        Workload environment. The current list of allowed
+        products can be found at
+        https://cloud.google.com/assured-workloads/docs/supported-products
+        In addition to assuredworkloads.workload.update
+        permission, the user should also have
+        orgpolicy.policy.set permission on the folder resource
+        to use this functionality.
+
+        Returns:
+            Callable[[~.RestrictAllowedResourcesRequest],
+                    ~.RestrictAllowedResourcesResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "restrict_allowed_resources" not in self._stubs:
+            self._stubs["restrict_allowed_resources"] = self.grpc_channel.unary_unary(
+                "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/RestrictAllowedResources",
+                request_serializer=assuredworkloads.RestrictAllowedResourcesRequest.serialize,
+                response_deserializer=assuredworkloads.RestrictAllowedResourcesResponse.deserialize,
+            )
+        return self._stubs["restrict_allowed_resources"]
+
     @property
     def delete_workload(
         self,
-    ) -> Callable[[assuredworkloads_v1beta1.DeleteWorkloadRequest], empty_pb2.Empty]:
+    ) -> Callable[[assuredworkloads.DeleteWorkloadRequest], empty_pb2.Empty]:
         r"""Return a callable for the delete workload method over gRPC.
 
         Deletes the workload. Make sure that workload's direct children
         are already in a deleted state, otherwise the request will fail
-        with a FAILED_PRECONDITION error.
+        with a FAILED_PRECONDITION error. In addition to
+        assuredworkloads.workload.delete permission, the user should
+        also have orgpolicy.policy.set permission on the deleted folder
+        to remove Assured Workloads OrgPolicies.
 
         Returns:
             Callable[[~.DeleteWorkloadRequest],
@@ -329,7 +362,7 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
         if "delete_workload" not in self._stubs:
             self._stubs["delete_workload"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/DeleteWorkload",
-                request_serializer=assuredworkloads_v1beta1.DeleteWorkloadRequest.serialize,
+                request_serializer=assuredworkloads.DeleteWorkloadRequest.serialize,
                 response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_workload"]
@@ -337,9 +370,7 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
     @property
     def get_workload(
         self,
-    ) -> Callable[
-        [assuredworkloads_v1beta1.GetWorkloadRequest], assuredworkloads_v1beta1.Workload
-    ]:
+    ) -> Callable[[assuredworkloads.GetWorkloadRequest], assuredworkloads.Workload]:
         r"""Return a callable for the get workload method over gRPC.
 
         Gets Assured Workload associated with a CRM Node
@@ -357,17 +388,46 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
         if "get_workload" not in self._stubs:
             self._stubs["get_workload"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/GetWorkload",
-                request_serializer=assuredworkloads_v1beta1.GetWorkloadRequest.serialize,
-                response_deserializer=assuredworkloads_v1beta1.Workload.deserialize,
+                request_serializer=assuredworkloads.GetWorkloadRequest.serialize,
+                response_deserializer=assuredworkloads.Workload.deserialize,
             )
         return self._stubs["get_workload"]
 
+    @property
+    def analyze_workload_move(
+        self,
+    ) -> Callable[
+        [assuredworkloads.AnalyzeWorkloadMoveRequest],
+        assuredworkloads.AnalyzeWorkloadMoveResponse,
+    ]:
+        r"""Return a callable for the analyze workload move method over gRPC.
+
+        Analyze if the source Assured Workloads can be moved
+        to the target Assured Workload
+
+        Returns:
+            Callable[[~.AnalyzeWorkloadMoveRequest],
+                    ~.AnalyzeWorkloadMoveResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "analyze_workload_move" not in self._stubs:
+            self._stubs["analyze_workload_move"] = self.grpc_channel.unary_unary(
+                "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/AnalyzeWorkloadMove",
+                request_serializer=assuredworkloads.AnalyzeWorkloadMoveRequest.serialize,
+                response_deserializer=assuredworkloads.AnalyzeWorkloadMoveResponse.deserialize,
+            )
+        return self._stubs["analyze_workload_move"]
+
     @property
     def list_workloads(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.ListWorkloadsRequest],
-        assuredworkloads_v1beta1.ListWorkloadsResponse,
+        [assuredworkloads.ListWorkloadsRequest], assuredworkloads.ListWorkloadsResponse
     ]:
         r"""Return a callable for the list workloads method over gRPC.
 
@@ -386,13 +446,53 @@ class AssuredWorkloadsServiceGrpcTransport(AssuredWorkloadsServiceTransport):
         if "list_workloads" not in self._stubs:
             self._stubs["list_workloads"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/ListWorkloads",
-                request_serializer=assuredworkloads_v1beta1.ListWorkloadsRequest.serialize,
-                response_deserializer=assuredworkloads_v1beta1.ListWorkloadsResponse.deserialize,
+                request_serializer=assuredworkloads.ListWorkloadsRequest.serialize,
+                response_deserializer=assuredworkloads.ListWorkloadsResponse.deserialize,
             )
         return self._stubs["list_workloads"]
 
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def get_operation(
+        self,
+    ) -> Callable[[operations_pb2.GetOperationRequest], operations_pb2.Operation]:
+        r"""Return a callable for the get_operation method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_operation" not in self._stubs:
+            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+                "/google.longrunning.Operations/GetOperation",
+                request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["get_operation"]
+
+    @property
+    def list_operations(
+        self,
+    ) -> Callable[
+        [operations_pb2.ListOperationsRequest], operations_pb2.ListOperationsResponse
+    ]:
+        r"""Return a callable for the list_operations method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_operations" not in self._stubs:
+            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+                "/google.longrunning.Operations/ListOperations",
+                request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
+                response_deserializer=operations_pb2.ListOperationsResponse.FromString,
+            )
+        return self._stubs["list_operations"]
+
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("AssuredWorkloadsServiceGrpcTransport",)
